==> spatstat_1.1-3.tar.gz: spatstat/data/amacrine.R <==
"amacrine" <-
structure(list(window = structure(list(type = "rectangle", xrange = c(0, 
1.6065), yrange = c(0, 1)), .Names = c("type", "xrange", "yrange"
), class = "owin"), n = 294, x = c(0.0224, 0.0243, 0.1626, 0.1215, 
0.2411, 0.0766, 0.1047, 0.043, 0.1084, 0.1981, 0.2505, 0.2215, 
0.3421, 0.2953, 0.3953, 0.4121, 0.3449, 0.3121, 0.0701, 0.0972, 
0.0757, 0.0299, 0.0393, 0.0757, 0.1972, 0.1561, 0.2159, 0.1935, 
0.2084, 0.228, 0.3383, 0.315, 0.3467, 0.3449, 0.4318, 0.4804, 
0.5243, 0.5215, 0.5075, 0.5991, 0.6393, 0.6402, 0.6262, 0.5748, 
0.4617, 0.4813, 0.472, 0.3636, 0.3505, 0.3, 0.2738, 0.2673, 0.3804, 
0.4327, 0.5037, 0.5477, 0.5645, 0.5271, 0.6103, 0.6598, 0.6542, 
0.6411, 0.7084, 0.7421, 0.7869, 0.7467, 0.6748, 0.6477, 0.614, 
0.671, 0.7495, 0.7495, 0.7654, 0.9056, 0.9093, 0.9355, 0.9056, 
0.986, 0.943, 0.7486, 0.7832, 0.7935, 0.7869, 0.9056, 0.8673, 
0.8636, 0.8065, 0.8636, 0.8533, 0.8561, 0.9346, 0.9991, 1.0645, 
1.0262, 0.9822, 1.029, 1.0673, 1.0869, 1.0981, 1.1607, 1.1093, 
1.1617, 1.2832, 1.3103, 1.4234, 1.4738, 1.4869, 1.557, 1.5972, 
1.5766, 1.586, 1.4804, 1.4234, 1.3355, 1.2206, 1.1402, 1.2477, 
1.3645, 1.3776, 1.5467, 1.5794, 1.5907, 1.4907, 1.4393, 1.3187, 
1.328, 1.2159, 1.185, 1.1766, 1.2561, 1.285, 1.3449, 1.3748, 
1.357, 1.4944, 1.5439, 1.5421, 1.4037, 1.4766, 1.4421, 1.5196, 
1.3271, 1.3075, 1.1935, 1.1972, 1.1925, 1.2682, 1.0318, 1.0785, 
1.0458, 1.0467, 1.0495, 0.072, 0.0766, 0.0944, 0.1523, 0.2065, 
0.2486, 0.2355, 0.2112, 0.1589, 0.328, 0.3449, 0.4009, 0.3748, 
0.3112, 0.0439, 0.1262, 0.1888, 0.3084, 0.2822, 0.214, 0.2822, 
0.228, 0.1262, 0.0112, 0.0346, 0.1262, 0.1598, 0.1916, 0.2738, 
0.3449, 0.4084, 0.3832, 0.3355, 0.4065, 0.4168, 0.4645, 0.5112, 
0.5346, 0.557, 0.4645, 0.5421, 0.6336, 0.7075, 0.7645, 0.8299, 
0.7533, 0.7262, 0.6308, 0.5308, 0.5243, 0.4383, 0.5271, 0.4187, 
0.5374, 0.5112, 0.4953, 0.5037, 0.5598, 0.6336, 0.6121, 0.6159, 
0.6355, 0.6187, 0.6748, 0.771, 0.8009, 0.7505, 0.7121, 0.7065, 
0.7495, 0.7308, 0.8972, 0.8514, 0.8215, 0.8168, 0.9075, 0.8598, 
0.9009, 0.8981, 0.7935, 0.8925, 0.9009, 0.9953, 0.943, 0.9991, 
0.9981, 0.9664, 1.0037, 0.9925, 0.972, 1.0421, 1.0047, 1.0701, 
1.1009, 1.0523, 1.1318, 1.0953, 1.1299, 1.1215, 1.1224, 1.0617, 
1.2178, 1.2234, 1.3738, 1.329, 1.4495, 1.5439, 1.5841, 1.4262, 
1.3252, 1.3944, 1.5028, 1.5178, 1.443, 1.4009, 1.2598, 1.2271, 
1.2505, 1.1944, 1.3327, 1.4579, 1.5785, 1.5935, 1.4318, 1.3822, 
1.3178, 1.285, 1.2682, 1.2019, 1.1925, 1.2701, 1.2159, 1.2346, 
1.3673, 1.3271, 1.4271, 1.4935, 1.5234, 1.5766, 1.5729, 1.457, 
1.4168), y = c(0.0243, 0.1028, 0.1477, 0.0729, 0.0486, 0.1776, 
0.2579, 0.3645, 0.4, 0.2841, 0.2776, 0.1617, 0.1963, 0.0729, 
0.0579, 0.1439, 0.2841, 0.3514, 0.5215, 0.657, 0.7355, 0.872, 
0.9869, 0.8252, 0.8617, 0.9411, 0.7757, 0.6533, 0.5458, 0.428, 
0.4776, 0.5832, 0.5636, 0.3832, 0.3262, 0.2542, 0.1925, 0.1159, 
0.0234, 0.0252, 0.1196, 0.2579, 0.3523, 0.3897, 0.4271, 0.4897, 
0.6822, 0.7551, 0.6953, 0.8112, 0.9084, 0.9813, 0.8785, 0.8402, 
0.8813, 0.9308, 0.8028, 0.5907, 0.6757, 0.7813, 0.8318, 0.972, 
0.9626, 0.8981, 0.7645, 0.6355, 0.6019, 0.5579, 0.472, 0.1841, 
0.2523, 0.0963, 0.0299, 0.1514, 0.2206, 0.2019, 0.3093, 0.3299, 
0.428, 0.4047, 0.4084, 0.3234, 0.4953, 0.515, 0.572, 0.6374, 
0.7093, 0.7486, 0.8495, 0.9579, 0.9009, 0.9888, 0.9262, 0.7916, 
0.6794, 0.5271, 0.4729, 0.5598, 0.6953, 0.7383, 0.8252, 0.9224, 
0.8514, 0.9766, 0.9112, 0.829, 0.9916, 0.9374, 0.9449, 0.8327, 
0.7729, 0.7121, 0.7981, 0.757, 0.7626, 0.6495, 0.6523, 0.6523, 
0.5598, 0.6037, 0.628, 0.4598, 0.4963, 0.4477, 0.4766, 0.5505, 
0.5299, 0.4168, 0.3047, 0.3832, 0.2589, 0.3421, 0.3607, 0.2262, 
0.3467, 0.2589, 0.1626, 0.1841, 0.1318, 0.0318, 0.0393, 0.0579, 
0.157, 0.1617, 0.0822, 0.0084, 0.014, 0.0486, 0.2196, 0.2374, 
0.2907, 0.3804, 0.0215, 0.1692, 0.2692, 0.3308, 0.3505, 0.2206, 
0.1327, 0.0617, 0.0916, 0.0206, 0.0785, 0.1121, 0.214, 0.3065, 
0.4589, 0.5664, 0.4514, 0.4131, 0.5252, 0.5841, 0.5991, 0.7103, 
0.6626, 0.8168, 0.9645, 0.8561, 0.9654, 0.8121, 0.8682, 0.9047, 
0.8944, 0.772, 0.7327, 0.6692, 0.6028, 0.6991, 0.7187, 0.7682, 
0.8093, 0.9486, 0.971, 0.8645, 0.9374, 0.971, 0.8486, 0.8271, 
0.7383, 0.6869, 0.6093, 0.5617, 0.4785, 0.3832, 0.3505, 0.2589, 
0.1748, 0.1019, 0.0785, 0.0841, 0.0318, 0.1355, 0.3093, 0.4206, 
0.5065, 0.571, 0.6028, 0.5243, 0.4486, 0.3336, 0.2374, 0.1523, 
0.0215, 0.043, 0.1383, 0.2327, 0.3103, 0.2626, 0.3776, 0.4598, 
0.5579, 0.6664, 0.715, 0.9514, 0.886, 0.8121, 0.7636, 0.6822, 
0.6084, 0.5542, 0.4336, 0.3075, 0.1505, 0.0645, 0.2308, 0.2551, 
0.3271, 0.3701, 0.4636, 0.5794, 0.7579, 0.8486, 0.9542, 0.1168, 
0.0037, 0.0318, 0.1224, 0.0757, 0.0542, 0.1449, 0.1916, 0.2243, 
0.2804, 0.2439, 0.3308, 0.3841, 0.3486, 0.3037, 0.2252, 0.3364, 
0.4421, 0.415, 0.4757, 0.529, 0.6252, 0.5533, 0.6252, 0.572, 
0.6514, 0.6925, 0.6589, 0.5822, 0.7505, 0.8654, 0.9374, 0.9411, 
0.8374, 0.8748, 0.8346, 0.9953, 0.8187, 0.729, 0.6822, 0.7374
), marks = structure(c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1), .Label = c("0", "1"), class = "factor")), .Names = c("window", 
"n", "x", "y", "marks"), class = "ppp")

==> spatstat_1.3-2.tar.gz: spatstat/data/amacrine.R <==
"amacrine" <-
structure(list(window = structure(list(type = "rectangle", xrange = c(0, 
1.6065), yrange = c(0, 1)), .Names = c("type", "xrange", "yrange"
), class = "owin"), n = 294, x = c(0.0224, 0.0243, 0.1626, 0.1215, 
0.2411, 0.0766, 0.1047, 0.043, 0.1084, 0.1981, 0.2505, 0.2215, 
0.3421, 0.2953, 0.3953, 0.4121, 0.3449, 0.3121, 0.0701, 0.0972, 
0.0757, 0.0299, 0.0393, 0.0757, 0.1972, 0.1561, 0.2159, 0.1935, 
0.2084, 0.228, 0.3383, 0.315, 0.3467, 0.3449, 0.4318, 0.4804, 
0.5243, 0.5215, 0.5075, 0.5991, 0.6393, 0.6402, 0.6262, 0.5748, 
0.4617, 0.4813, 0.472, 0.3636, 0.3505, 0.3, 0.2738, 0.2673, 0.3804, 
0.4327, 0.5037, 0.5477, 0.5645, 0.5271, 0.6103, 0.6598, 0.6542, 
0.6411, 0.7084, 0.7421, 0.7869, 0.7467, 0.6748, 0.6477, 0.614, 
0.671, 0.7495, 0.7495, 0.7654, 0.9056, 0.9093, 0.9355, 0.9056, 
0.986, 0.943, 0.7486, 0.7832, 0.7935, 0.7869, 0.9056, 0.8673, 
0.8636, 0.8065, 0.8636, 0.8533, 0.8561, 0.9346, 0.9991, 1.0645, 
1.0262, 0.9822, 1.029, 1.0673, 1.0869, 1.0981, 1.1607, 1.1093, 
1.1617, 1.2832, 1.3103, 1.4234, 1.4738, 1.4869, 1.557, 1.5972, 
1.5766, 1.586, 1.4804, 1.4234, 1.3355, 1.2206, 1.1402, 1.2477, 
1.3645, 1.3776, 1.5467, 1.5794, 1.5907, 1.4907, 1.4393, 1.3187, 
1.328, 1.2159, 1.185, 1.1766, 1.2561, 1.285, 1.3449, 1.3748, 
1.357, 1.4944, 1.5439, 1.5421, 1.4037, 1.4766, 1.4421, 1.5196, 
1.3271, 1.3075, 1.1935, 1.1972, 1.1925, 1.2682, 1.0318, 1.0785, 
1.0458, 1.0467, 1.0495, 0.072, 0.0766, 0.0944, 0.1523, 0.2065, 
0.2486, 0.2355, 0.2112, 0.1589, 0.328, 0.3449, 0.4009, 0.3748, 
0.3112, 0.0439, 0.1262, 0.1888, 0.3084, 0.2822, 0.214, 0.2822, 
0.228, 0.1262, 0.0112, 0.0346, 0.1262, 0.1598, 0.1916, 0.2738, 
0.3449, 0.4084, 0.3832, 0.3355, 0.4065, 0.4168, 0.4645, 0.5112, 
0.5346, 0.557, 0.4645, 0.5421, 0.6336, 0.7075, 0.7645, 0.8299, 
0.7533, 0.7262, 0.6308, 0.5308, 0.5243, 0.4383, 0.5271, 0.4187, 
0.5374, 0.5112, 0.4953, 0.5037, 0.5598, 0.6336, 0.6121, 0.6159, 
0.6355, 0.6187, 0.6748, 0.771, 0.8009, 0.7505, 0.7121, 0.7065, 
0.7495, 0.7308, 0.8972, 0.8514, 0.8215, 0.8168, 0.9075, 0.8598, 
0.9009, 0.8981, 0.7935, 0.8925, 0.9009, 0.9953, 0.943, 0.9991, 
0.9981, 0.9664, 1.0037, 0.9925, 0.972, 1.0421, 1.0047, 1.0701, 
1.1009, 1.0523, 1.1318, 1.0953, 1.1299, 1.1215, 1.1224, 1.0617, 
1.2178, 1.2234, 1.3738, 1.329, 1.4495, 1.5439, 1.5841, 1.4262, 
1.3252, 1.3944, 1.5028, 1.5178, 1.443, 1.4009, 1.2598, 1.2271, 
1.2505, 1.1944, 1.3327, 1.4579, 1.5785, 1.5935, 1.4318, 1.3822, 
1.3178, 1.285, 1.2682, 1.2019, 1.1925, 1.2701, 1.2159, 1.2346, 
1.3673, 1.3271, 1.4271, 1.4935, 1.5234, 1.5766, 1.5729, 1.457, 
1.4168), y = c(0.0243, 0.1028, 0.1477, 0.0729, 0.0486, 0.1776, 
0.2579, 0.3645, 0.4, 0.2841, 0.2776, 0.1617, 0.1963, 0.0729, 
0.0579, 0.1439, 0.2841, 0.3514, 0.5215, 0.657, 0.7355, 0.872, 
0.9869, 0.8252, 0.8617, 0.9411, 0.7757, 0.6533, 0.5458, 0.428, 
0.4776, 0.5832, 0.5636, 0.3832, 0.3262, 0.2542, 0.1925, 0.1159, 
0.0234, 0.0252, 0.1196, 0.2579, 0.3523, 0.3897, 0.4271, 0.4897, 
0.6822, 0.7551, 0.6953, 0.8112, 0.9084, 0.9813, 0.8785, 0.8402, 
0.8813, 0.9308, 0.8028, 0.5907, 0.6757, 0.7813, 0.8318, 0.972, 
0.9626, 0.8981, 0.7645, 0.6355, 0.6019, 0.5579, 0.472, 0.1841, 
0.2523, 0.0963, 0.0299, 0.1514, 0.2206, 0.2019, 0.3093, 0.3299, 
0.428, 0.4047, 0.4084, 0.3234, 0.4953, 0.515, 0.572, 0.6374, 
0.7093, 0.7486, 0.8495, 0.9579, 0.9009, 0.9888, 0.9262, 0.7916, 
0.6794, 0.5271, 0.4729, 0.5598, 0.6953, 0.7383, 0.8252, 0.9224, 
0.8514, 0.9766, 0.9112, 0.829, 0.9916, 0.9374, 0.9449, 0.8327, 
0.7729, 0.7121, 0.7981, 0.757, 0.7626, 0.6495, 0.6523, 0.6523, 
0.5598, 0.6037, 0.628, 0.4598, 0.4963, 0.4477, 0.4766, 0.5505, 
0.5299, 0.4168, 0.3047, 0.3832, 0.2589, 0.3421, 0.3607, 0.2262, 
0.3467, 0.2589, 0.1626, 0.1841, 0.1318, 0.0318, 0.0393, 0.0579, 
0.157, 0.1617, 0.0822, 0.0084, 0.014, 0.0486, 0.2196, 0.2374, 
0.2907, 0.3804, 0.0215, 0.1692, 0.2692, 0.3308, 0.3505, 0.2206, 
0.1327, 0.0617, 0.0916, 0.0206, 0.0785, 0.1121, 0.214, 0.3065, 
0.4589, 0.5664, 0.4514, 0.4131, 0.5252, 0.5841, 0.5991, 0.7103, 
0.6626, 0.8168, 0.9645, 0.8561, 0.9654, 0.8121, 0.8682, 0.9047, 
0.8944, 0.772, 0.7327, 0.6692, 0.6028, 0.6991, 0.7187, 0.7682, 
0.8093, 0.9486, 0.971, 0.8645, 0.9374, 0.971, 0.8486, 0.8271, 
0.7383, 0.6869, 0.6093, 0.5617, 0.4785, 0.3832, 0.3505, 0.2589, 
0.1748, 0.1019, 0.0785, 0.0841, 0.0318, 0.1355, 0.3093, 0.4206, 
0.5065, 0.571, 0.6028, 0.5243, 0.4486, 0.3336, 0.2374, 0.1523, 
0.0215, 0.043, 0.1383, 0.2327, 0.3103, 0.2626, 0.3776, 0.4598, 
0.5579, 0.6664, 0.715, 0.9514, 0.886, 0.8121, 0.7636, 0.6822, 
0.6084, 0.5542, 0.4336, 0.3075, 0.1505, 0.0645, 0.2308, 0.2551, 
0.3271, 0.3701, 0.4636, 0.5794, 0.7579, 0.8486, 0.9542, 0.1168, 
0.0037, 0.0318, 0.1224, 0.0757, 0.0542, 0.1449, 0.1916, 0.2243, 
0.2804, 0.2439, 0.3308, 0.3841, 0.3486, 0.3037, 0.2252, 0.3364, 
0.4421, 0.415, 0.4757, 0.529, 0.6252, 0.5533, 0.6252, 0.572, 
0.6514, 0.6925, 0.6589, 0.5822, 0.7505, 0.8654, 0.9374, 0.9411, 
0.8374, 0.8748, 0.8346, 0.9953, 0.8187, 0.729, 0.6822, 0.7374
), marks = structure(c(2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 
2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
1, 1, 1, 1, 1, 1, 1, 1), .Label = c("off", "on"), class = "factor")), .Names = c("window", 
"n", "x", "y", "marks"), class = "ppp")
